==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_fields/CONTRACTTEMPLATEDISCOUNTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CONTRACTTEMPLATEDISCOUNTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CONTRACTTEMPLATEDISCOUNTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONTRACTTEMPLATEDISCOUNTCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CONTRACTTEMPLATEDISCOUNTID_Type", propOrder = {
    "contracttemplatediscountcode"
})
public class CONTRACTTEMPLATEDISCOUNTID_Type {

    @XmlElement(name = "CONTRACTTEMPLATEDISCOUNTCODE", required = true)
    protected String contracttemplatediscountcode;

    /**
     * Obtient la valeur de la propriété contracttemplatediscountcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCONTRACTTEMPLATEDISCOUNTCODE() {
        return contracttemplatediscountcode;
    }

    /**
     * Définit la valeur de la propriété contracttemplatediscountcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCONTRACTTEMPLATEDISCOUNTCODE(String value) {
        this.contracttemplatediscountcode = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/CONTRACTTEMPLATEDISCOUNTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CONTRACTTEMPLATEDISCOUNTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CONTRACTTEMPLATEDISCOUNTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONTRACTTEMPLATEDISCOUNTCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CONTRACTTEMPLATEDISCOUNTID_Type", propOrder = {
    "contracttemplatediscountcode"
})
public class CONTRACTTEMPLATEDISCOUNTID_Type {

    @XmlElement(name = "CONTRACTTEMPLATEDISCOUNTCODE", required = true)
    protected String contracttemplatediscountcode;

    /**
     * Gets the value of the contracttemplatediscountcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCONTRACTTEMPLATEDISCOUNTCODE() {
        return contracttemplatediscountcode;
    }

    /**
     * Sets the value of the contracttemplatediscountcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCONTRACTTEMPLATEDISCOUNTCODE(String value) {
        this.contracttemplatediscountcode = value;
    }

}
